"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

var _reactDom = _interopRequireDefault(require("react-dom"));

var _testUtils = _interopRequireDefault(require("react-dom/test-utils"));

var _immutable = require("immutable");

var _Menu = _interopRequireDefault(require("@instructure/ui-menu/lib/components/Menu"));

var _Link = _interopRequireDefault(require("@instructure/ui-elements/lib/components/Link"));

var _Bank = _interopRequireDefault(require("../../../../common/records/Bank"));

var _presenter = _interopRequireDefault(require("../presenter"));

var _featureCheck = require("../../../../common/util/featureCheck");

var styles = {
  componentId: 'eShTv',
  template: function template(theme) {
    return "\n\n.eShTv_dIMK{border-bottom:".concat(theme.bankRowBorderWidth || 'inherit', " solid ").concat(theme.bankRowBorderColor || 'inherit', ";display:flex;flex-direction:row}\n\n.eShTv_Zupb{flex:1;margin:").concat(theme.bankInfoMargin || 'inherit', " 0}\n\n.eShTv_qnWp{font-size:").concat(theme.bankTitleFontSize || 'inherit', ";padding-bottom:").concat(theme.bankTitlePadding || 'inherit', "}\n\n.eShTv_ciks{color:").concat(theme.bankDetailsColor || 'inherit', ";font-size:").concat(theme.bankDetailsFontSize || 'inherit', "}\n\n.eShTv_cCNg{margin:").concat(theme.bankOptionsMargin || 'inherit', " 0}\n\n.eShTv_bISW{font-size:").concat(theme.BankOptionIconFontSize || 'inherit', ";margin-right:").concat(theme.BankOptionIconMargin || 'inherit', ";vertical-align:middle}\n\n.eShTv_AHIw{display:block}\n\n.eShTv_eTBd{margin-bottom:").concat(theme.deletePrefaceMargin || 'inherit', "}");
  },
  'bankRow': 'eShTv_dIMK',
  'bankInfo': 'eShTv_Zupb',
  'bankTitle': 'eShTv_qnWp',
  'bankDetails': 'eShTv_ciks',
  'bankOptions': 'eShTv_cCNg',
  'bankOptionIcon': 'eShTv_bISW',
  'deleteAlert': 'eShTv_AHIw',
  'deletePreface': 'eShTv_eTBd'
};
describe('BanksList', function () {
  var navigateToBankStub = sinon.stub();
  var openModalStub = sinon.stub();
  var withConfirmStub = sinon.stub();
  var deleteBankStub = sinon.stub();
  var focusCreateBankButtonStub = sinon.stub();
  var bank1 = new _Bank.default({
    id: '1',
    updatedAt: new Date('2017-03-14 14:01 UTC'),
    title: 'Algebraic',
    sharedCount: 2
  });
  var bank2 = new _Bank.default({
    id: '999',
    updatedAt: Date.now(),
    title: 'Mathematical',
    sharedCount: 0
  });
  var banks = (0, _immutable.List)([bank1, bank2]);
  var testbed = createTestbed(withContext(_presenter.default), {
    banks: banks,
    navigateToBank: navigateToBankStub
  });
  var shallowBanksListTestbed = createTestbed(_presenter.default, {
    banks: banks,
    focusCreateBankButton: focusCreateBankButtonStub,
    deleteBank: deleteBankStub,
    navigateToBank: navigateToBankStub,
    openModal: openModalStub,
    withConfirm: withConfirmStub
  });
  afterEach(function () {
    deleteBankStub.resetHistory();
    focusCreateBankButtonStub.resetHistory();
    navigateToBankStub.resetHistory();
    openModalStub.resetHistory();
    withConfirmStub.resetHistory();
  });
  it('renders each bank', function () {
    testbed.render();
    var rows = testbed.findChildrenByClass(styles.bankInfo);
    expect(rows.length).to.eq(2);
    expect(testbed.getText(rows[0])).to.include('Algebraic');
    expect(testbed.getText(rows[0])).to.include('Updated Mar 14');
  });
  it('navigates to bank', function () {
    testbed.render();
    var rows = testbed.findChildrenBySelector(".".concat(styles.bankRow, " button"));

    _testUtils.default.Simulate.click(rows[2]);

    expect(navigateToBankStub.calledWith('999')).to.be.true();
  });
  it('opens edit bank modal', function () {
    var shallowTestbed = shallowBanksListTestbed.renderShallowly();
    shallowTestbed.instance().openModal({
      id: '2'
    })();
    expect(openModalStub.calledWith('EDIT_BANK_MODAL:2')).to.be.true();
  });
  it('renders edit and delete options', function () {
    testbed.render();
    var menu = testbed.findChildrenByType(_Menu.default)[0];
    expect(menu.props.children.length).to.equal(2);
  });
  describe('deleteBank', function () {
    it('opens a confirmation modal when deleting a bank', function () {
      var shallowTestbed = shallowBanksListTestbed.renderShallowly();
      shallowTestbed.instance().openDeleteBankModal('1')();
      expect(withConfirmStub).to.have.been.called();
    });
    it('calls delete bank', function () {
      var shallowTestbed = shallowBanksListTestbed.renderShallowly();
      shallowTestbed.instance().deleteBank('1');
      expect(deleteBankStub).to.have.been.calledWith('1');
    });
    it('focuses the create bank button', function (done) {
      var shallowTestbed = shallowBanksListTestbed.renderShallowly();
      shallowTestbed.instance().deleteBank('1');
      setTimeout(function () {
        expect(focusCreateBankButtonStub).to.have.been.called();
        done();
      }, 150);
    });
  });
  describe('sharing', function () {
    (0, _featureCheck.withTestFeatures)(['item_bank_sharing']);
    it('should render the link to share', function () {
      testbed.render();
      expect(testbed.getText()).to.include('Share');
    });
    it('should open the modal when the link is clicked', function () {
      var subject = testbed.render();
      var shareLink = testbed.findChildrenByType(_Link.default)[3];
      shareLink.props.onClick();
      expect(subject.refs.composedComponent.state.sharingModalOpen).to.be.true();
    });
    it('should close the modal when dismissed', function () {
      var subject = testbed.render();
      var comp = subject.refs.composedComponent;
      comp.handleSharingModalDismiss();
      expect(subject.refs.composedComponent.state.sharingModalOpen).to.be.false();
    });
    it('should display +share when shareCount is 0', function () {
      testbed.render();
      var shareLink = testbed.findChildrenByType(_Link.default)[3];

      var SharedLinkNode = _reactDom.default.findDOMNode(shareLink);

      expect(SharedLinkNode.innerText).to.include('+ Share');
    });
    it('should display Sharing(shareCount) when shareCount > 0', function () {
      testbed.render();
      var shareLink = testbed.findChildrenByType(_Link.default)[1];

      var SharedLinkNode = _reactDom.default.findDOMNode(shareLink);

      expect(SharedLinkNode.innerText).to.include('Sharing (2)');
    });
  });
  it('should meet a11y standards', function (done) {
    testbed.render();
    testbed.checkA11yStandards(done, {
      ignores: ['aria-allowed-role' // TODO: remove this when instui fixes Select
      ]
    });
  });
});